==> nextcloud-28.0.7.tgz: nextcloud/apps/suspicious_login/l10n/cs.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Zjištěno nové místo přihlášení",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Další informace získáte kliknutím na tlačítko, které otevře %s a zobrazí další informace o podezřelé IP adrese.",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Bylo zaznamenáno nové přihlášení k vašemu účtu. IP adresa %s byla vyhodnocena jako podezřelá. Pokud jste to byli vy, tuto zprávu ignorujte. Pokud ne, měli byste si změnit heslo.",
    "More information ↗" : "Další informace",
    "Suspicious Login" : "Podezřelé přihlášení",
    "New login detected" : "Zjištěno nové přihlášení",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Zjišťovat a varovat o podezřelých IP adresách přihlašujících se k Nextcloud\n\t",
    "Suspicious login detection" : "Zjišťování podezřelých přihlášení",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Na této instanci je zapnutá služba sledování podezřelých přihlášení. Uchovává záznam o IP adresách ze kterých se uživatelé úspěšně přihlásili a vytváří hodnocení, které varuje, pokud nové přihlášení přichází z podezřelé iP adresy.",
    "Training data statistics" : "Statistiky trénovacích údajů",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Doposud aplikace zachytila {total} přihlášení (včetně připojení z klientských aplikací), z kterých {distinct} jsou neopakující se dvojice (IP adresa, UID identifikátor).",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Statistiky modelu hodnocení",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Doposud nebyl natrénován žádný model hodnocení. To nejspíš znamená, že jste aplikaci zapnuli teprve nedávno. Protože natrénování modelu vyžaduje dobrá data, aplikace čeká dokud nejsou zachycena přihlášení po dobu alespoň {days}.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "V průběhu vyhodnocování, nejnovější model (trénován {time}) ukázal zachytit {recall}% všech podezřelých přihlášení (recall), zatímco {precision}% přihlášení, klasifikovaných jako podezřelé je také podezřelé (přesnost). Níže vidíte znázornění výkonu historického modelu.",
    "Precision" : "Přesnost",
    "Recall" : "Vyvolat"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/suspicious_login/l10n/cs.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Zjištěno nové místo přihlášení",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Bylo zaznamenáno nové přihlášení k vašemu účtu. IP adresa %s byla vyhodnocena jako podezřelá. Pokud jste to byli vy, tuto zprávu ignorujte. Pokud ne, měli byste si změnit heslo.",
    "Suspicious Login" : "Podezřelé přihlášení",
    "New login detected" : "Zjištěno nové přihlášení",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Zjišťovat a varovat o podezřelých IP adresách přihlašujících se k Nextcloud\n\t",
    "Suspicious login detection" : "Zjišťování podezřelých přihlášení",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Na této instanci je zapnutá služba sledování podezřelých přihlášení. Uchovává záznam o IP adresách ze kterých se uživatelé úspěšně přihlásili a vytváří hodnocení, které varuje, pokud nové přihlášení přichází z podezřelé iP adresy.",
    "Training data statistics" : "Statistiky trénovacích údajů",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Doposud aplikace zachytila {total} přihlášení (včetně připojení z klientských aplikací), z kterých {distinct} jsou neopakující se dvojice (IP adresa, UID identifikátor).",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Statistiky modelu hodnocení",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Doposud nebyl natrénován žádný model hodnocení. To nejspíš znamená, že jste aplikaci zapnuli teprve nedávno. Protože natrénování modelu vyžaduje dobrá data, aplikace čeká dokud nejsou zachycena přihlášení po dobu alespoň {days}.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "V průběhu vyhodnocování, nejnovější model (trénován {time}) ukázal zachytit {recall}% všech podezřelých přihlášení (recall), zatímco {precision}% přihlášení, klasifikovaných jako podezřelé je také podezřelé (přesnost). Níže vidíte znázornění výkonu historického modelu.",
    "Precision" : "Přesnost",
    "Recall" : "Vyvolat",
    "More information ↗" : "Další informace",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Další informace získáte kliknutím na tlačítko, které otevře %s a zobrazí další informace o podezřelé IP adrese."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
